==> gnuhealth-3.0.4.tar.gz: gnuhealth-3.0.4/health_stock/__init__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
#    GNU Health: The Free Health and Hospital Information System
#    Copyright (C) 2008-2016 Luis Falcon <lfalcon@gnusolidario.org>
#    Copyright (C) 2011-2016 GNU Solidario <health@gnusolidario.org>
#
#    Copyright (C) 2013  Sebastian Marro <smarro@gnusolidario.org>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from trytond.pool import Pool
from .health_stock import *
from wizard import *

def register():
    Pool.register(
        Medicament,
        Party,
        Lot,
        Move,
        PatientAmbulatoryCare,
        PatientAmbulatoryCareMedicament,
        PatientAmbulatoryCareMedicalSupply,
        PatientRounding,
        PatientRoundingMedicament,
        PatientRoundingMedicalSupply,
        PatientPrescriptionOrder,
        PatientVaccination,
        CreatePrescriptionStockMoveInit,
        CreateVaccinationStockMoveInit,
        module='health_stock', type_='model')
    Pool.register(
        CreatePrescriptionStockMove,
        CreateVaccinationStockMove,
        module='health_stock', type_='wizard')

==> gnuhealth-3.6.3.tar.gz: gnuhealth-3.6.3/health_stock/__init__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
#    GNU Health: The Free Health and Hospital Information System
#    Copyright (C) 2008-2020 Luis Falcon <lfalcon@gnusolidario.org>
#    Copyright (C) 2011-2020 GNU Solidario <health@gnusolidario.org>
#
#    Copyright (C) 2013  Sebastian Marro <smarro@gnusolidario.org>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from trytond.pool import Pool
from .health_stock import *
from .wizard import *

def register():
    Pool.register(
        Party,
        Lot,
        Move,
        PatientAmbulatoryCare,
        PatientAmbulatoryCareMedicament,
        PatientAmbulatoryCareMedicalSupply,
        PatientRounding,
        PatientRoundingMedicament,
        PatientRoundingMedicalSupply,
        PatientPrescriptionOrder,
        PatientVaccination,
        CreatePrescriptionStockMoveInit,
        CreateVaccinationStockMoveInit,
        module='health_stock', type_='model')
    Pool.register(
        CreatePrescriptionStockMove,
        CreateVaccinationStockMove,
        module='health_stock', type_='wizard')
